@@ -1,9 +1,19 @@
+( cd opt/kde/share/doc/HTML/pt_BR/ark ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/ark ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdm ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kate ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kdvi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kdvi ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kppp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kppp ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kxkb ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/katomic ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/katomic ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/ksysguard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/ksysguard ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbounce ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbattleship ; rm -rf common )
@@ -12,14 +22,30 @@
 ( cd opt/kde/share/doc/HTML/pt_BR/cervisia ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdesu ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcron ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kfind ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcoloredit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/klipper ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/klipper ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kompare ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/konsole ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/konquest ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/konquest ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kspaceduel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kmenuedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kioslave ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf fdl-license )
@@ -128,6 +154,8 @@
 ( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/powerctrl ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cookies ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filetypes ; rm -rf common )
@@ -224,6 +252,8 @@
 ( cd opt/kde/share/doc/HTML/pt_BR/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kbabel ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kamera ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kamera ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdeprint ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kasteroids ; rm -rf common )
@@ -232,8 +262,26 @@
 ( cd opt/kde/share/doc/HTML/pt_BR/keduca ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kicker ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kpager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kpager ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kspell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kspell ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kstars ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kstars ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kwrite ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kwrite ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kreversi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kreversi ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/ksplashml ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kblackbox ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kblackbox ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcharselect ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/kcharselect ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/quanta ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pci ; rm -rf common )
@@ -274,3 +322,7 @@
 ( cd opt/kde/share/doc/HTML/pt_BR/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
 ( cd opt/kde/share/doc/HTML/pt_BR/umbrello ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt_BR/umbrello ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/konqueror ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/konqueror ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
+( cd opt/kde/share/doc/HTML/pt_BR/atlantik ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt_BR/atlantik ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
